dart_vm_service_library library

Dart VM Service library.

This library provides tools for interacting with the Dart VM Service, allowing for debugging and introspection of Dart applications.

Classes

AncestorDescendantRequest
Request for ancestor/descendant widget tapping
BoolValueRequest
Request with a boolean value
ConnectRequest
Request to connect to a Flutter app
ConnectResponse
Response from connect request
DartVmServiceBase
DartVmServiceClient
DartVmServiceGrpcServer
The main gRPC server for Dart VM Service. Use this class to start and stop the gRPC service.
DartVmServiceTool
Tool that exposes the Dart VM Service API.
DetailSubtreeRequest
Request for detailed subtree
DisplayRefreshRateResponse
Response with display refresh rate
DisposeIdRequest
Request for disposing an object ID
DoubleValueRequest
Request with a double value
EmptyRequest
Empty request for methods that don't need parameters
EnterTextAncestorDescendantRequest
Request for entering text by ancestor and descendant
EnterTextKeyRequest
Request for entering text by key
EnterTextRequest
Request for entering text
EnterTextTextRequest
Request for entering text by text
EnterTextTooltipRequest
Request for entering text by tooltip
EnterTextTypeRequest
Request for entering text by type
FlexFactorRequest
Request for flex factor
FlexFitRequest
Request for flex fit
FlexPropertiesRequest
Request for flex properties
FlutterExtensionUtils
A utility class for interacting with Flutter's service extension APIs.
FlutterFinderExtensionUtils
GenericResponse
Generic response message
LayoutExplorerRequest
Request for layout explorer
ListViewsResponse
Response with views
ObjectGroupRequest
Request with object group
ScreenshotRequest
Request for screenshot
ScrollAncestorDescendantRequest
Request for scroll ancestor and descendant
ScrollIntoViewAncestorDescendantRequest
Request for scroll into view by ancestor and descendant
ScrollIntoViewKeyRequest
Request for scroll into view by key
ScrollIntoViewTextRequest
Request for scroll into view by text
ScrollIntoViewTooltipRequest
Request for scroll into view by tooltip
ScrollIntoViewTypeRequest
Request for scroll into view by type
ScrollKeyRequest
Request for scroll key
ScrollTextRequest
Request for scroll text
ScrollTooltipRequest
Request for scroll tooltip
ScrollTypeRequest
Request for scroll type
SelectedWidgetRequest
Request for selected widget
SelectionByIdRequest
Request for selection by ID
StringListRequest
Request with a list of strings
StringListResponse
Response with a list of strings
StringValueRequest
Request with a string value
ToggleRequest
Toggle request for features that can be enabled/disabled
ToggleResponse
Toggle response
TreeDumpResponse
Tree dump response
ViewIdRequest
Request with a view ID
WidgetRequest
Request for widget operations

Enums

CrossAxisAlignment
Enum for cross axis alignment values.
FlexFit
Enum for flex fit values.
MainAxisAlignment
Enum for main axis alignment values.

Extensions

CrossAxisAlignmentExtension on CrossAxisAlignment
FlexFitExtension on FlexFit
Extension methods for enum serialization
GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.
MainAxisAlignmentExtension on MainAxisAlignment