FlutterExtensionUtils class

A utility class for interacting with Flutter's service extension APIs.

This provides a Dart implementation of the VM service extension functions with proper parameter handling based on the Flutter framework's expectations.

Constructors

FlutterExtensionUtils(VmService vmService)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vmService → VmService
final

Methods

activeDevToolsServerAddress(String isolateId, {String? value}) Future<Response>
Sets or gets the active DevTools server address.
addPubRootDirectories(String isolateId, List<String> args) Future<Response>
Adds pub root directories.
brightnessOverride(String isolateId, {String? value}) Future<Response>
Overrides the brightness.
connectedVmServiceUri(String isolateId, {String? value}) Future<Response>
Sets or gets the connected VM service URI.
debugAllowBanner(String isolateId, {bool? enabled}) Future<Response>
Toggles the debug banner.
debugDisableOpacityLayers(String isolateId, {bool? enabled}) Future<Response>
Toggles disabling of opacity layers.
debugDisablePhysicalShapeLayers(String isolateId, {bool? enabled}) Future<Response>
Toggles disabling of physical shape layers.
debugDumpApp(String isolateId) Future<Response>
Dumps the application widget tree.
debugDumpFocusTree(String isolateId) Future<Response>
Dumps the focus tree.
debugDumpLayerTree(String isolateId) Future<Response>
Dumps the layer tree.
debugDumpRenderTree(String isolateId) Future<Response>
Dumps the render tree.
debugDumpSemanticsTreeInInverseHitTestOrder(String isolateId) Future<Response>
Dumps the semantics tree in inverse hit test order.
debugDumpSemanticsTreeInTraversalOrder(String isolateId) Future<Response>
Dumps the semantics tree in traversal order.
debugPaint(String isolateId, {bool? enabled}) Future<Response>
Toggles debug paint mode.
debugPaintBaselinesEnabled(String isolateId, {bool? enabled}) Future<Response>
Toggles baseline painting.
didSendFirstFrameEvent(String isolateId, {bool? enabled}) Future<Response>
Sets or queries the first frame event status.
didSendFirstFrameRasterizedEvent(String isolateId, {String? enabled}) Future<Response>
Sets or queries the first frame rasterized event status.
disposeAllGroups(String isolateId, String objectGroup) Future<Response>
Disposes all object groups.
disposeGroup(String isolateId, String objectGroup) Future<Response>
Disposes a specific object group.
disposeId(String isolateId, String objectGroup, {String? objectId}) Future<Response>
Disposes a specific object by ID.
evict(String isolateId, {String? value}) Future<Response>
Evicts assets from cache.
exit(String isolateId) Future<Response>
Exits the application.
getChildren(String isolateId, String objectGroup, {String? diagnosticableId}) Future<Response>
Gets children of a diagnosticable object.
getChildrenDetailsSubtree(String isolateId, String objectGroup, {String? diagnosticableId}) Future<Response>
Gets details subtree of children of a diagnosticable object.
getChildrenSummaryTree(String isolateId, String objectGroup, {String? diagnosticableId}) Future<Response>
Gets summary tree of children of a diagnosticable object.
getDetailsSubtree(String isolateId, String objectGroup, {String? diagnosticableId, int? subtreeDepth}) Future<Response>
Gets details subtree of a diagnosticable object.
getDisplayRefreshRate(String viewId) Future<Response>
Gets the display refresh rate for a view.
getLayoutExplorerNode(String isolateId, String objectGroup, {String? id, int? subtreeDepth}) Future<Response>
Gets the layout explorer node.
getParentChain(String isolateId, String objectGroup, {String? objectId}) Future<Response>
Gets the parent chain of a widget.
getProperties(String isolateId, String objectGroup, {String? diagnosticableId}) Future<Response>
Gets properties of a diagnosticable object.
getPubRootDirectories(String isolateId) Future<Response>
Gets the list of pub root directories.
getRootWidget(String isolateId, {String? objectGroup}) Future<Response>
Gets the root widget.
getRootWidgetSummaryTree(String isolateId, {String? objectGroup}) Future<Response>
Gets the summary tree of the root widget.
getRootWidgetSummaryTreeWithPreviews(String isolateId, {String? objectGroup}) Future<Response>
Gets the summary tree of the root widget with previews.
getSelectedSummaryWidget(String isolateId, String objectGroup, {String? previousSelectionId}) Future<Response>
Gets the selected summary widget.
getSelectedWidget(String isolateId, String objectGroup, {String? previousSelectionId}) Future<Response>
Gets the selected widget.
invertOversizedImage(String isolateId, {bool? enabled}) Future<Response>
Toggles the display of oversized images.
isWidgetCreationTracked(String isolateId) Future<Response>
Checks if widget creation is tracked.
isWidgetTreeReady(String isolateId) Future<Response>
Checks if the widget tree is ready.
listViews() Future<Response>
Lists all the Flutter views available.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
platformOverride(String isolateId, {String? value}) Future<Response>
Overrides the platform.
profilePlatformChannels(String isolateId, {bool? enabled}) Future<Response>
Toggles profiling of platform channels.
profileRenderObjectLayouts(String isolateId, {bool? enabled}) Future<Response>
Toggles profiling of render object layouts.
profileRenderObjectPaints(String isolateId, {bool? enabled}) Future<Response>
Toggles profiling of render object paints.
profileUserWidgetBuilds(String isolateId, {bool? enabled}) Future<Response>
Toggles profiling of user widget builds.
profileWidgetBuilds(String isolateId, {bool? enabled}) Future<Response>
Toggles profiling of widget builds.
reassemble(String isolateId) Future<Response>
Triggers reassemble of the application.
removePubRootDirectories(String isolateId, List<String> args) Future<Response>
Removes pub root directories.
repaintRainbow(String isolateId, {bool? enabled}) Future<Response>
Toggles repaint rainbow effect.
screenshot(String isolateId, String id, double width, double height, {double? margin, double? maxPixelRatio, bool? debugPaint}) Future<Response>
Takes a screenshot of a widget.
setFlexFactor(String isolateId, {String? id, int? flexFactor}) Future<Response>
Sets flex factor on a widget.
setFlexFit(String isolateId, {String? id, String? flexFit}) Future<Response>
Sets flex fit on a widget.
setFlexProperties(String isolateId, {String? id, String? mainAxisAlignment, String? crossAxisAlignment}) Future<Response>
Sets flex properties on a widget.
setPubRootDirectories(String isolateId, List<String> args) Future<Response>
Sets pub root directories.
setSelectionById(String isolateId, String objectGroup, {String? objectId}) Future<Response>
Sets widget selection by ID.
show(String isolateId, {bool? enabled}) Future<Response>
Toggles inspector visibility.
showPerformanceOverlay(String isolateId, {bool? enabled}) Future<Response>
Toggles the performance overlay.
structuredErrors(String isolateId, {bool? enabled}) Future<Response>
Toggles structured error reporting.
timeDilation(String isolateId, {String? value}) Future<Response>
Sets time dilation factor.
toString() String
A string representation of this object.
inherited
trackRebuildDirtyWidgets(String isolateId, {bool? enabled}) Future<Response>
Toggles tracking of widget rebuilds.
trackRepaintWidgets(String isolateId, {bool? enabled}) Future<Response>
Toggles tracking of widget repaints.

Operators

operator ==(Object other) bool
The equality operator.
inherited